@@ -52,7 +52,7 @@ impl Execution {
     /// ## Parameter Errors
     ///
     /// Missing parameters, extra parameters, or parameters of the wrong type will all cause errors.
-    pub(crate) async fn run<C: Client>(
+    pub(crate) async fn run<C: Client + ?Sized>(
         &self,
         shots: NonZeroU16,
         addresses: HashMap<String, AddressRequest>,
@@ -81,8 +81,8 @@ mod describe_execution {
     use super::{Execution, Parameters};
     use crate::{client::Qcs, qvm};
 
-    async fn qvm_client() -> qvm::http::HttpClient {
-        let qcs = Qcs::load().await;
+    fn qvm_client() -> qvm::http::HttpClient {
+        let qcs = Qcs::load();
         qvm::http::HttpClient::from(&qcs)
     }
 
@@ -98,7 +98,7 @@ mod describe_execution {
                 NonZeroU16::new(1).expect("value is non-zero"),
                 HashMap::new(),
                 &params,
-                &qvm_client().await,
+                &qvm_client(),
             )
             .await;
         if let Err(e) = result {
@@ -120,7 +120,7 @@ mod describe_execution {
                 NonZeroU16::new(1).expect("value is non-zero"),
                 HashMap::new(),
                 &params,
-                &qvm_client().await,
+                &qvm_client(),
             )
             .await;
         if let Err(e) = result {
