@@ -6,8 +6,8 @@ use qcs::compiler::quilc::{
 use qcs_api_client_openapi::models::InstructionSetArchitecture;
 use quil_rs::quil::Quil;
 use rigetti_pyo3::{
-    create_init_submodule, impl_repr, py_wrap_data_struct, py_wrap_error, py_wrap_struct,
-    py_wrap_type,
+    create_init_submodule, impl_repr, py_function_sync_async, py_wrap_data_struct, py_wrap_error,
+    py_wrap_struct, py_wrap_type,
     pyo3::{
         exceptions::{PyRuntimeError, PyValueError},
         pyclass, pyfunction, pymethods,
@@ -17,7 +17,6 @@ use rigetti_pyo3::{
     wrap_error, PyWrapper, ToPythonError,
 };
 
-use crate::py_sync::py_function_sync_async;
 use crate::qpu::isa::PyInstructionSetArchitecture;
 
 create_init_submodule! {
